@@ -1,17 +1,14 @@
 from __future__ import annotations
 from dataclasses import dataclass, field, asdict
-from datetime import timedelta
-from datetime import datetime
 from enum import Enum
 from pathlib import Path
 import sys
-from typing import Optional, List
+from typing import List
 from urllib.parse import urlparse
 from functools import lru_cache
 import json
 
 import click
-import jwt
 import yaml
 from rich.prompt import Prompt
 
@@ -21,9 +18,7 @@ from threedi_api_client.aio.threedi_api_client import (
     ThreediApiClient as AsyncThreediApiClient,
 )
 
-from openapi_client.api.auth_api import AuthApi
 from threedi_api_client.threedi_api_client import (
-    is_token_usable,
     get_auth_token,
     refresh_api_key,
 )
