@@ -1,18 +1,18 @@
 from .base import SettingsWrapper
 from openapi_client import SimulationsApi
 from openapi_client.models import (
-    GeneralSettings,
+    PhysicalSettings,
     NumericalSettings,
     TimeStepSettings,
     AggregationSettings
 )
 
 
-class GeneralSettingsWrapper(SettingsWrapper):
+class PhysicalSettingsWrapper(SettingsWrapper):
     api_class = SimulationsApi
-    model = GeneralSettings
-    api_path: str = "general"
-    scenario_name = "generalsettings"
+    model = PhysicalSettings
+    api_path: str = "physical"
+    scenario_name = "physicalsettings"
 
 
 class NumercialSettingsWrapper(SettingsWrapper):
@@ -37,7 +37,7 @@ class AggregationSettingsWrapper(SettingsWrapper):
 
 
 WRAPPERS = [
-    GeneralSettingsWrapper,
+    PhysicalSettingsWrapper,
     NumercialSettingsWrapper,
     TimeStepSettingsWrapper,
     AggregationSettingsWrapper
